==> haskell-onetuple-0.3.1-75-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 OneTuple
version:              0.3.1
visibility:           public
id:                   OneTuple-0.3.1-FCz2xnE00b94Ogh6y4sDd8
key:                  OneTuple-0.3.1-FCz2xnE00b94Ogh6y4sDd8
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = Solo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  b382e2fbd9869728792973bce845b17e
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/OneTuple-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/OneTuple-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.3.1-FCz2xnE00b94Ogh6y4sDd8
depends:
    base-4.16.4.0 ghc-prim-0.8.0 template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-onetuple-0.4.1-7-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-onetuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 OneTuple
version:              0.4.1
visibility:           public
id:                   OneTuple-0.4.1-HV7N8vLWC8GJ6CEaZb8jlF
key:                  OneTuple-0.4.1-HV7N8vLWC8GJ6CEaZb8jlF
license:              BSD-3-Clause
copyright:            (c) John Dorsey 2008
maintainer:
    Oleg Grenrus <oleg.grenrus@iki.fi>, John Dorsey <haskell@colquitt.org>

author:               John Dorsey <haskell@colquitt.org>
stability:            experimental
synopsis:             Singleton Tuple
description:
    This package is a compatibility package for a singleton data type

    > data Solo a = MkSolo a

    Note: it'\''s not a @newtype@

    @Solo@ is available in @base-4.16@ (GHC-9.2).

category:             Data
abi:                  9123217956bb04dd2f4fe876a70906bd
exposed:              True
exposed-modules:
    Data.Tuple.OneTuple Data.Tuple.Solo Data.Tuple.Solo.TH

import-dirs:          /usr/lib/ghc-9.2.8/site-local/OneTuple-0.4.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/OneTuple-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-onetuple
hs-libraries:         HSOneTuple-0.4.1-HV7N8vLWC8GJ6CEaZb8jlF
depends:
    base-4.16.4.0 ghc-prim-0.8.0 template-haskell-2.18.0.0

haddock-interfaces:   /usr/share/doc/haskell-onetuple/html/OneTuple.haddock
haddock-html:         /usr/share/doc/haskell-onetuple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
